pub struct SnapshotCoverage {
pub entities: bool,
pub edges: bool,
pub notes: bool,
}Expand description
Records which record classes are covered by a KG snapshot.
v1 covers entities and edges only. Notes are excluded until note packs define versioned export, import, privacy/redaction, and merge semantics.
Fields
entities: booledges: boolnotes: boolTrait Implementations
Sourceimpl Clone for SnapshotCoverage
impl Clone for SnapshotCoverage
Sourcefn clone(&self) -> SnapshotCoverage
fn clone(&self) -> SnapshotCoverage
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SnapshotCoverage
impl Debug for SnapshotCoverage
Sourceimpl<'de> Deserialize<'de> for SnapshotCoverage
impl<'de> Deserialize<'de> for SnapshotCoverage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SnapshotCoverage
Sourceimpl PartialEq for SnapshotCoverage
impl PartialEq for SnapshotCoverage
Sourceimpl Serialize for SnapshotCoverage
impl Serialize for SnapshotCoverage
impl StructuralPartialEq for SnapshotCoverage